==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skrooge_tracker/skgtrackerpluginwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGTRACKERPLUGINWIDGET_H
#define SKGTRACKERPLUGINWIDGET_H
/** @file
 * A skrooge plugin to track operations
*
* @author Stephane MANKOWSKI
*/
#include "ui_skgtrackerpluginwidget_base.h"
#include "skgtabwidget.h"

class SKGObjectModel;

/**
 * A skrooge plugin to track operations
 */
class SKGTrackerPluginWidget : public SKGTabWidget
{
        Q_OBJECT

public:
        /**
         * Default Constructor
         */
        SKGTrackerPluginWidget(SKGDocument* iDocument);

        /**
         * Default Destructor
         */
        virtual ~SKGTrackerPluginWidget();

        /**
         * Get the current state
         * MUST BE OVERWRITTEN
         * @return a string containing all information needed to set the same state.
         * Could be an XML stream
         */
        virtual QString getState();

        /**
         * Set the current state
         * MUST BE OVERWRITTEN
         * @param iState must be interpreted to set the state of the widget
         */
        virtual void setState(const QString& iState);

        /**
         * Get attribute name to save the default state
         * MUST BE OVERWRITTEN
         * @return attribute name to save the default state.
         */
        virtual QString getDefaultStateAttribute();

        /**
         * Get the widget must be printed
         * @return a widget
         */
        virtual QWidget* getWidgetForPrint();

        /**
         * Get the current selection
         * @return selected objects
         */
        virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();

        /**
         * Get the number of seleted object
         * @return number of selected objects
         */
        virtual int getNbSelectedObjects();

private slots:
        void dataModified(const QString& iTableName, int iIdTransaction);
        void onDoubleClick();
        void onSelectionChanged();
        void onEditorModified();
        void onAddTracker();
        void onModifyTracker();
        void onFilterChanged();
        void cleanEditor();

private:
        Q_DISABLE_COPY(SKGTrackerPluginWidget);

        Ui::skgtrackerplugin_base ui;
        SKGObjectModel* objectModel;
};

#endif // SKGTRACKERPLUGINWIDGET_H

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skrooge_tracker/skgtrackerpluginwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGTRACKERPLUGINWIDGET_H
#define SKGTRACKERPLUGINWIDGET_H
/** @file
 * A skrooge plugin to track operations
*
* @author Stephane MANKOWSKI
*/
#include "ui_skgtrackerpluginwidget_base.h"
#include "skgtabpage.h"

class SKGObjectModel;

/**
 * A skrooge plugin to track operations
 */
class SKGTrackerPluginWidget : public SKGTabPage
{
        Q_OBJECT

public:
        /**
         * Default Constructor
         */
        SKGTrackerPluginWidget(SKGDocument* iDocument);

        /**
         * Default Destructor
         */
        virtual ~SKGTrackerPluginWidget();

        /**
         * Get the current state
         * MUST BE OVERWRITTEN
         * @return a string containing all information needed to set the same state.
         * Could be an XML stream
         */
        virtual QString getState();

        /**
         * Set the current state
         * MUST BE OVERWRITTEN
         * @param iState must be interpreted to set the state of the widget
         */
        virtual void setState(const QString& iState);

        /**
         * Get attribute name to save the default state
         * MUST BE OVERWRITTEN
         * @return attribute name to save the default state.
         */
        virtual QString getDefaultStateAttribute();

        /**
         * Get the widget must be printed
         * @return a widget
         */
        virtual QWidget* getWidgetForPrint();

        /**
         * Get the current selection
         * @return selected objects
         */
        virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();

        /**
         * Get the number of seleted object
         * @return number of selected objects
         */
        virtual int getNbSelectedObjects();

protected:
        /**
         * Event filtering
         * @param object object
         * @param event event
         * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
         */
        virtual bool eventFilter ( QObject *object, QEvent *event );

private slots:
        void dataModified(const QString& iTableName, int iIdTransaction);
        void onDoubleClick();
        void onSelectionChanged();
        void onEditorModified();
        void onAddTracker();
        void onModifyTracker();
        void onFilterChanged();
        void cleanEditor();

private:
        Q_DISABLE_COPY(SKGTrackerPluginWidget);

        Ui::skgtrackerplugin_base ui;
        SKGObjectModel* objectModel;
};

#endif // SKGTRACKERPLUGINWIDGET_H
